Engine

Struct Engine 

pub struct Engine {
    pub camera: Arc<Mutex<PerspectiveCamera>>,
    /* private fields */
}
High-level engine structure for building and rendering scenes.

Handles Vulkan context, swapchain, render pass, rendering pipeline, inputs, and the physics simulation loop.

Fields

camera: Arc<Mutex<PerspectiveCamera>>

Implementations

Source

impl Engine

pub fn new(title: &str) -> Self

Creates a new Engine and initializes Vulkan, Winit, and rendering pipelines.

Arguments
  • title - The window title.
Examples
let engine = rusting_engine::Engine::new("My Game");
pub fn set_light(&mut self, pos: [f32; 3], color: [f32; 3], intensity: f32)

Set the sun in scene

pub fn add_cube(&mut self, transform: Transform, mat: &Material, phys: &Physics)

Adding a cube to the scene.

Example
engine.add_cube(
   Transform {
       ..Default::default()
   },
   &Material::standard()
       .build(),
   &Physics::default()
       .collision(0.2), // type, if collision < 0.5 => Box, collision > 0.5 => Sphere
   );
pub fn add_sphere( &mut self, transform: Transform, mat: &Material, phys: &Physics, )

Adding a sphere to the scene.

Example
engine.add_sphere(
   Transform {
       ..Default::default()
   },
   &Material::standard()
       .build(),
   &Physics::default()
       .collision(0.8), // type, if collision < 0.5 => Box, collision > 0.5 => Sphere
   );
pub fn set_scene_shader(&mut self, shader: ShaderType)

Set a scene-wide shader override. All objects will use this shader.

pub fn clear_scene_shader(&mut self)

Clear the scene-wide shader override. Objects will use their per-object shader.

pub fn set_scene_physic(&mut self, shader: ComputeShaderType)

Set a scene-wide shader override. All objects will use this shader.

pub fn clear_scene_physic(&mut self)

Clear the scene-wide shader override. Objects will use their per-object shader.

pub fn run(self)

Starts the engine’s main loop.

This method will block the current thread until the window is closed. It handles event dispatch, physics update intervals, and issues continuous draw calls.